@@ -44,6 +44,7 @@
 #include "kz-actions-download.h"
 #include "kz-about-dialog.h"
 #include "kz-paned.h"
+#include "kz-bookmark-menu.h"
 
 static GQuark bookmark_quark = 0;
 
@@ -224,7 +225,6 @@ act_forward (EggAction *action, KzWindow *kz)
 }
 
 
-/*
 static void
 act_show_history_menu (EggAction *action, KzWindow *kz)
 {
@@ -233,6 +233,7 @@ act_show_history_menu (EggAction *action, KzWindow *kz)
 	GtkWidget *menu;
 	KzBookmark *history;
 	KzMozEmbed *kzembed = KZ_MOZ_EMBED(KZ_WINDOW_CURRENT_PAGE(kz));
+	guint32 activate_time;
 
 	history = kz_bookmark_pure_folder_new();
 	kz_bookmark_set_title(history, _("History"));
@@ -245,20 +246,21 @@ act_show_history_menu (EggAction *action, KzWindow *kz)
 	for (i = 0; i < count; i++)
 	{
 		KzBookmark *bookmark;
-		gchar *title, *url;
+		gchar *title, *uri;
 	
 		kz_moz_embed_shistory_get_nth (kzembed, i, FALSE,
-					       &url, &title);
+					       &uri, &title);
 		bookmark = kz_bookmark_new_with_attrs(title, uri, NULL);
 		kz_bookmark_prepend(history, bookmark);
 		g_object_unref(bookmark);	
 	}
 	gtk_widget_show(menu);
+	activate_time = gtk_get_current_event_time();
 	kz_actions_popup_bookmark_menu_modal(kz, history,
-					     NULL,
-					     NULL);
+					     0,
+					     activate_time);
 }
-*/
+
 
 static void
 act_go_up (EggAction *action, KzWindow *kz)
@@ -858,6 +860,7 @@ act_add_bookmark (EggAction *action, KzWindow *kz)
 	KzBookmark *folder, *bookmark, *sibling = NULL;
 	GtkWidget *widget;
 	const gchar *title, *uri;
+	gchar *desc;
 
 	g_return_if_fail(KZ_IS_WINDOW (kz));
 
@@ -876,10 +879,11 @@ act_add_bookmark (EggAction *action, KzWindow *kz)
 
 	title = kz_moz_embed_ensure_title(KZ_MOZ_EMBED(widget));
 	uri   = kz_moz_embed_get_location(KZ_MOZ_EMBED(widget));
+	desc  = kz_moz_embed_get_selection_string(KZ_MOZ_EMBED(widget));
 
 	if (!uri) return;
 
-	bookmark = kz_bookmark_new_with_attrs(title, uri, NULL);
+	bookmark = kz_bookmark_new_with_attrs(title, uri, desc);
 	/* FIXME! show dialog */
 	if (sibling)
 		kz_bookmark_insert_before(folder, bookmark, sibling);
@@ -887,6 +891,9 @@ act_add_bookmark (EggAction *action, KzWindow *kz)
 		kz_bookmark_append(folder, bookmark);
 	if (kz_bookmark_is_file(folder))
 		kz_bookmark_save(folder);
+	if (desc)
+		g_free(desc);
+
 	g_object_unref(G_OBJECT(bookmark));
 }
 
@@ -1078,13 +1085,16 @@ act_restore_session (EggAction *action, KzWindow *kz)
 		if (!key_seems_sequential(key, "tab")) continue;
 
 		uri = kz_profile_get_string(kz_session, current_session, key);
-		kz_window_open_new_tab(kz, uri);
+		kz_window_open_new_tab_at_position(kz, uri, i);
 		g_free(uri);
 		/*
 		 * gtk_notebook_append_page() always emits 
 		 * "switch-page" signal with page num which is 0 value, so
 		 * we should call gtk_notebook_set_current_page with correct page number.
  		 */
+		/*
+		 * 2004-02-01: This isn't necessary any more because tab position sets.
+		 */ 
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(kz->notebook), i);
 		i++;
 	}
