@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
- *  Copyright (C) 2002 Hiroyuki Ikezoe
+ *  Copyright (C) 2002-2004 Hiroyuki Ikezoe
  *  Copyright (C) 2003 Takuro Ashie
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 #include "egg-menu-merge.h"
 #include "kz-gesture.h"
 #include "kz-embed-event.h"
+#include "kz-favicon.h"
 
 G_BEGIN_DECLS
 
@@ -70,6 +71,9 @@ struct _KzWindow
 	EggActionGroup *tabpop_actions;
 	EggMenuMerge   *menu_merge;
 
+	/* handle for favicon */
+	KzFavicon *kzfav;
+
 	KzWindowPriv *priv;
 };
 
@@ -94,6 +98,9 @@ GtkWidget        *kz_window_new                      (const gchar *url);
 GtkWidget        *kz_window_get_from_tab             (GtkWidget   *tab_widget);
 GtkWidget        *kz_window_open_new_tab             (KzWindow    *kz,
 						      const gchar *url);
+GtkWidget        *kz_window_open_new_tab_at_position (KzWindow    *kz,
+						      const gchar *url,
+						      gint pos);
 GtkWidget        *kz_window_open_new_tab_with_parent (KzWindow    *kz,
 						      const gchar *url,
 						      GtkWidget   *parent);
