@@ -114,7 +114,7 @@ static void egg_toolbar_real_style_changed       (EggToolbar      *toolbar,
 static gboolean             egg_toolbar_button_press         (GtkWidget      *button,
 							      GdkEventButton *event,
 							      EggToolbar     *toolbar);
-static void                 egg_toolbar_arrow_button_press   (GtkWidget      *button,
+static gboolean             egg_toolbar_arrow_button_press   (GtkWidget      *button,
 							      GdkEventButton *event,
 							      EggToolbar     *toolbar);
 static void                 egg_toolbar_update_button_relief (EggToolbar     *toolbar);
@@ -1319,7 +1319,7 @@ menu_deactivated (GtkWidget *menu, GtkWidget *button)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
 }
 
-static void
+static gboolean
 egg_toolbar_arrow_button_press (GtkWidget      *button,
     				GdkEventButton *event,
 				EggToolbar     *toolbar)
@@ -1357,6 +1357,8 @@ egg_toolbar_arrow_button_press (GtkWidget      *button,
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
 		  menu_position_func, toolbar,
 		  event->button, event->time);
+
+  return TRUE;
 }
 
 static gboolean
